@@ -11,7 +11,6 @@ from models import Story
 
 info_dict = {
     'queryset': Story.published.all(),
-    'template_object_name': 'story',
     'date_field': 'publish_date',
     'allow_empty': True
 }
@@ -27,43 +26,37 @@ urlpatterns = patterns('',
     # news archive index
     url(
         r'^$',
-        ArchiveIndexView.as_view(),
-        info_dict,
+        ArchiveIndexView.as_view(**info_dict),
         name='news_archive_index'
     ),
     # news archive year list
     url(
         r'^(?P<year>\d{4})/$',
-        YearArchiveView.as_view(),
-        info_dict,
+        YearArchiveView.as_view(**info_dict),
         name='news_archive_year'
     ),
     # news archive month list
     url(
         r'^(?P<year>\d{4})/(?P<month>\w{3})/$',
-        MonthArchiveView.as_view(),
-        info_dict,
+        MonthArchiveView.as_view(**info_dict),
         name='news_archive_month'
     ),
     # news archive week list
     url(
         r'^(?P<year>\d{4})/(?P<week>\d{1,2})/$',
-        WeekArchiveView.as_view(),
-        info_dict,
+        WeekArchiveView.as_view(**info_dict),
         name='news_archive_week'
     ),
     # news archive day list
     url(
         r'^(?P<year>\d{4})/(?P<month>\w{3})/(?P<day>\d{2})/$',
-        DayArchiveView.as_view(),
-        info_dict,
+        DayArchiveView.as_view(**info_dict),
         name='news_archive_day'
     ),
     # news archive today list
     url(
         r'^today/$',
-        TodayArchiveView.as_view(),
-        info_dict,
+        TodayArchiveView.as_view(**info_dict),
         name='news_archive_day'
     ),
     # story detail
@@ -75,15 +68,13 @@ urlpatterns = patterns('',
     #story print detail
     url(
         r'^(?P<year>\d{4})/(?P<month>\w{3})/(?P<day>\d{1,2})/(?P<slug>[-\w]+)/print/$',
-        DateDetailView.as_view(),
-        print_info_dict,
+        DateDetailView.as_view(**print_info_dict),
         name='news_detail_print',
     ),
     #story comments
     url(
         r'^(?P<year>\d{4})/(?P<month>\w{3})/(?P<day>\d{1,2})/(?P<slug>[-\w]+)/comments/$',
-        DateDetailView.as_view(),
-        comment_info_dict,
+        DateDetailView.as_view(**comment_info_dict),
         name='news_detail_comments',
     ),
 
